@@ -1,5 +1,5 @@
 package POE::Component::Curl::Multi;
-$POE::Component::Curl::Multi::VERSION = '0.06';
+$POE::Component::Curl::Multi::VERSION = '0.08';
 #ABSTRACT: a fast HTTP POE component
 
 use strict;
@@ -214,16 +214,17 @@ sub _request {
       $easy->setopt(CURLOPT_PROXY, $proxy) if $proxy;
     }
 
+    my @extra_headers;
+    if (my $content = $req->content) {
+        $easy->setopt(CURLOPT_POSTFIELDS, $content);
+        push @extra_headers, 'Expect:';
+    }
+
     $easy->setopt(CURLOPT_TIMEOUT, $self->{timeout});
     $easy->setopt( $methods{ $req->method }, 1 );
     $easy->setopt(CURLOPT_CUSTOMREQUEST, $req->method);
     $easy->setopt(CURLOPT_HTTPHEADER,
-        [ split "\n", $req->headers->as_string ]);
-
-    if (my $content = $req->content) {
-        $easy->setopt(CURLOPT_POSTFIELDS, $content);
-        $easy->setopt(CURLOPT_POSTFIELDSIZE, length $content);
-    }
+        [ split( m!\x0D\x0A!, $req->headers_as_string("\x0D\x0A") ), @extra_headers ]);
 
     $easy->setopt(CURLOPT_VERBOSE, 1) if $self->{curl_debug};
 
@@ -370,7 +371,7 @@ POE::Component::Curl::Multi - a fast HTTP POE component
 
 =head1 VERSION
 
-version 0.06
+version 0.08
 
 =head1 SYNOPSIS
 
